<?php
/*
	WARNING! DO NOT EDIT THIS FILE!
	This file is part of the core Bizznis parent theme. 
	Please do all modifications in the form of a child theme.
*/

/**
 * This file controls the top-level Bizznis menu.
 *
 * @since 1.0.0
 */
add_action( 'after_setup_theme', 'bizznis_add_admin_menu' );
function bizznis_add_admin_menu() {
	# Stop here, if not viewing the admin
	if ( ! is_admin() ) {
		return;
	}
	# Global variable
	global $_bizznis_admin_settings;
	# Don't add menu item if programatically disabled
	if ( ! current_theme_supports( 'bizznis-admin-menu' ) ) {
		return;
	}
	# Current user object
	$user = wp_get_current_user();
	# Don't add menu item if disabled for current user
	if ( ! get_the_author_meta( 'bizznis_admin_menu', $user->ID ) ) {
		return;
	}
	# Add "Settings" submenu item
	new Bizznis_Admin_Settings;
	# Hook here to create submenus
	do_action( 'bizznis_admin_menu' );

}

/**
 * Add submenu items under Bizznis in admin menu.
 *
 * @since 0.2.0
 */
add_action( 'bizznis_admin_menu', 'bizznis_add_admin_submenus' );
function bizznis_add_admin_submenus() {
	# Stop here, if not viewing the admin
	if ( ! is_admin() ) {
		return;
	}
	# Global variable
	global $_bizznis_admin_seo_settings, $_bizznis_admin_tools, $_bizznis_admin_readme;
	# Don't add submenu items if Bizznis menu is disabled
	if( ! current_theme_supports( 'bizznis-admin-menu' ) ) {
		return;
	}
	# Get current user
	$user = wp_get_current_user();
	# Add "SEO Settings" submenu item
	if ( current_theme_supports( 'bizznis-seo-settings-menu' ) && get_the_author_meta( 'bizznis_seo_settings_menu', $user->ID ) ) {
		// Disabled SEO options: $_bizznis_admin_seo_settings = new Bizznis_Admin_SEO_Settings;
	}
	# Add "Import/Export Settings" submenu item
	if ( current_theme_supports( 'bizznis-tools-settings-menu' ) && get_the_author_meta( 'bizznis_tools_settings_menu', $user->ID ) ) {
		$_bizznis_admin_tools = new Bizznis_Admin_Import_Export;
	}
	# Add the about page (no menu)
	new Bizznis_Admin_About;
}

/**
 * Add the feedback link to admin navigation
 *
 * @since 1.0.0
 */
add_action( 'bizznis_admin_title_right', 'bizznis_add_admin_menu_feedback', 15 );
function bizznis_add_admin_menu_feedback() {
	printf( __( '<a href="%s" target="_blank" class="feedback" title="Report a Bug">Report a Bug</a>', 'bizznis' ), esc_url( 'https://github.com/bizzthemes/bizznis/issues' ) );
}

/**
 * Add bizznis theme settings menus to admin bar on front
 *
 * @since 1.0.2
 */
add_action( 'admin_bar_menu', 'bizznis_link_to_theme_settings', 999 );
function bizznis_link_to_theme_settings( $wp_admin_bar ) {
	# Stop here, if viewing the admin
	if ( is_admin() ) {
		return;
	}
	# Don't add menu item if programatically disabled
	if( ! current_theme_supports( 'bizznis-admin-menu' ) ) {
		return;
	}
	$wp_admin_bar->add_node( array(
		'id'    	=> 'theme-settings',
		'title' 	=> __( 'Theme Settings', 'bizznis' ),
		'href'  	=> add_query_arg( array( 'page' => 'bizznis' ), admin_url( 'themes.php' ) ),
		'parent'	=> 'site-name',
	) );
	# Get current user
	$user = wp_get_current_user();
	if ( current_theme_supports( 'bizznis-seo-settings-menu' ) && get_the_author_meta( 'bizznis_seo_settings_menu', $user->ID ) ) {
		$wp_admin_bar->add_node( array(
			'id'    	=> 'theme-seo',
			'title' 	=> __( 'Theme SEO', 'bizznis' ),
			'href'  	=> add_query_arg( array( 'page' => 'bizznis-seo' ), admin_url( 'themes.php' ) ),
			'parent'	=> 'site-name',
		) );
	}
	if ( current_theme_supports( 'bizznis-tools-settings-menu' ) && get_the_author_meta( 'bizznis_tools_settings_menu', $user->ID ) ) {
		$wp_admin_bar->add_node( array(
			'id'    	=> 'theme-tools',
			'title' 	=> __( 'Theme Tools', 'bizznis' ),
			'href'  	=> add_query_arg( array( 'page' => 'bizznis-tools' ), admin_url( 'themes.php' ) ),
			'parent'	=> 'site-name',
		) );
	}
}