<?php
/*
	WARNING! DO NOT EDIT THIS FILE!
	This file is part of the core Bizznis parent theme. 
	Please do all modifications in the form of a child theme.
*/

/**
 * Disable the Bizznis SEO features.
 *
 * @since 1.0.0
 */
function bizznis_disable_seo() {
	remove_filter( 'wp_title', 'bizznis_default_title', 10, 3 );
	remove_action( 'get_header', 'bizznis_doc_head_control' );
	remove_action( 'wp_head','bizznis_seo_meta_description' );
	remove_action( 'wp_head','bizznis_robots_meta' );
	remove_action( 'wp_head','bizznis_canonical', 5 );
	remove_action( 'wp_head', 'bizznis_rel_author' );
	remove_action( 'wp_head', 'bizznis_rel_publisher' );
	remove_action( 'admin_menu', 'bizznis_add_inpost_seo_box' );
	remove_action( 'save_post', 'bizznis_inpost_seo_save', 1, 2 );
	remove_action( 'admin_init', 'bizznis_add_taxonomy_seo_options' );
	remove_action( 'show_user_profile', 'bizznis_user_seo_fields' );
	remove_action( 'edit_user_profile', 'bizznis_user_seo_fields' );
	remove_filter( 'user_contactmethods', 'bizznis_user_contactmethods' );
	remove_theme_support( 'bizznis-seo-settings-menu' );
	add_filter( 'pre_option_' . BIZZNIS_SEO_SETTINGS_FIELD, '__return_empty_array' );
	define( 'BIZZNIS_SEO_DISABLED', true );
}

/**
 * Detect whether or not Bizznis SEO has been disabled.
 *
 * @since 1.0.0
 */
function bizznis_seo_disabled() {
	if ( defined( 'BIZZNIS_SEO_DISABLED' ) && BIZZNIS_SEO_DISABLED ) {
		return true;
	}
	return false;
}

/**
 * Check for the existence of popular SEO plugins and disable the Bizznis SEO features if
 * one or more of the plugins is active.
 *
 * @since 1.0.0
 */
add_action( 'after_setup_theme', 'bizznis_seo_compatibility_check', 5 );
function bizznis_seo_compatibility_check() {
	if ( bizznis_detect_seo_plugins() ) {
		bizznis_disable_seo();
	}
	# Disable Bizznis <title> generation if SEO Title Tag is active
	if ( function_exists( 'seo_title_tag' ) ) {
		remove_filter( 'wp_title', 'bizznis_default_title', 10, 3 );
		remove_action( 'wp_head', 'wp_title' );
		add_action( 'wp_head', 'seo_title_tag', 1 );
	}
}

/**
 * Detect some SEO Plugin that add constants, classes or functions.
 *
 * @since 1.0.0
 */
function bizznis_detect_seo_plugins() {
	return bizznis_detect_plugin(
		# Use this filter to adjust plugin tests.
		apply_filters(
			'bizznis_detect_seo_plugins',
			# Add to this array to add new plugin checks.
			array(
				# Classes to detect.
				'classes' => array(
					'All_in_One_SEO_Pack',
					'All_in_One_SEO_Pack_p',
					'HeadSpace_Plugin',
					'Platinum_SEO_Pack',
					'wpSEO',
					'SEO_Ultimate',
				),
				# Functions to detect.
				'functions' => array(),
				# Constants to detect.
				'constants' => array( 'WPSEO_VERSION', ),
			)
		)
	);
}
